summaryrefslogtreecommitdiffstats
path: root/kdat/VerifyOptDlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/VerifyOptDlg.h')
-rw-r--r--kdat/VerifyOptDlg.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kdat/VerifyOptDlg.h b/kdat/VerifyOptDlg.h
index 48a3624..faa94a7 100644
--- a/kdat/VerifyOptDlg.h
+++ b/kdat/VerifyOptDlg.h
@@ -32,6 +32,7 @@ class TQLineEdit;
*/
class VerifyOptDlg : public TQDialog {
Q_OBJECT
+ TQ_OBJECT
bool _restore;
TQString _workingDir;
TQLineEdit* _entry;
@@ -45,10 +46,10 @@ public:
* @param def The default working directory.
* @param files The list of files that will be verified/restored.
* @param restore TRUE means we are doing a restore, FALSE means we are doing a verify.
* @param parent The parent widget for the dialog.
* @param name The name for the dialog.
*/
- VerifyOptDlg( const TQString & def, const TQStringList& files, bool restore = FALSE, TQWidget* parent = 0, const char* name = 0 );
+ VerifyOptDlg( const TQString & def, const TQStringList& files, bool restore = FALSE, TQWidget* tqparent = 0, const char* name = 0 );
/**
* Destroy the verify/restore options dialog.
@@ -45,10 +46,10 @@ public:
* @param files The list of files that will be verified/restored.
* @param restore TRUE means we are doing a restore, FALSE means we are doing a verify.
- * @param parent The parent widget for the dialog.
+ * @param tqparent The tqparent widget for the dialog.
* @param name The name for the dialog.
*/